@@ -42,14 +42,22 @@ INVALID_ID_STRINGS = (
 	"N/A", "n/a",
 	"12345", "54321", "202020",
 	"Chassis", "chassis",
+	"EVAL",
 	"Not Applicable",
 	"None", "empty",
+	"System Serial Number",
+	"XXXXX",
 	"01010101-0101-0101-0101-010101010101",
 	"00020003-0004-0005-0006-000700080009",
 	"03000200-0400-0500-0006-000700080009",
+	"11111111-1111-1111-1111-111111111111",
 	"0000000", "00000000",
 )
 
+INVALID_ID_STRINGS_EXACT_MATCH = (
+	"NA",
+)
+
 class Singleton(type):
 	def __init__(cls, name, bases, dict):
 		super(Singleton, cls).__init__(name, bases, dict)
@@ -234,11 +242,17 @@ class System(object):
 			if id is None:
 				continue
 
-			for i in INVALID_ID_STRINGS:
-				if i in id:
+			for i in INVALID_ID_STRINGS_EXACT_MATCH:
+				if id == i:
 					id = None
 					break
 
+			if id:
+				for i in INVALID_ID_STRINGS:
+					if i in id:
+						id = None
+						break
+
 			if id:
 				_ids.append(id)
 
